#
# spec file for package perl-IPC-System-Simple
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-IPC-System-Simple
Version:        1.30
Release:        1.19
%define cpan_name IPC-System-Simple
Summary:        Run commands simply, with detailed diagnostics
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JK/JKEENAN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Calling Perl's in-built 'system()' function is easy, determining if it was
successful is _hard_. Let's face it, '$?' isn't the nicest variable in the
world to play with, and even if you _do_ check it, producing a
well-formatted error string takes a lot of work.

'IPC::System::Simple' takes the hard work out of calling external commands.
In fact, if you want to be really lazy, you can just write:

    use IPC::System::Simple qw(system);

and all of your 'system' commands will either succeed (run to completion
and return a zero exit value), or die with rich diagnostic messages.

The 'IPC::System::Simple' module also provides a simple replacement to
Perl's backticks operator. Simply write:

    use IPC::System::Simple qw(capture);

and then use the capture() command just like you'd use backticks. If
there's an error, it will die with a detailed description of what went
wrong. Better still, you can even use 'capturex()' to run the equivalent of
backticks, but without the shell:

    use IPC::System::Simple qw(capturex);

    my $result = capturex($command, @args);

If you want more power than the basic interface, including the ability to
specify which exit values are acceptable, trap errors, or process
diagnostics, then read on!

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples README
%license LICENSE

%changelog
* Tue Mar 24 2020 <timueller+perl@suse.de>
- updated to 1.30
  see /usr/share/doc/packages/perl-IPC-System-Simple/Changes
* Sun Jan 26 2020 <timueller+perl@suse.de>
- updated to 1.26
  see /usr/share/doc/packages/perl-IPC-System-Simple/Changes
  1.26      2020-01-25 02:00:45+00:00 UTC
  1.26      2020-01-24 20:47 America/NewYork
  * BUILD: Update FAIL_POSIX warning message
    Per:  https://github.com/pjf/ipc-system-simple/pull/28.  Thanks to scop.
  * TEST: t/07_taint.t: Use executable name as source of taintedness
    Addresses https://github.com/pjf/ipc-system-simple/issues/21
    Thanks to Petr Písař.
  * OTHER: Typographic corrections:
    rt.cpan.org 60211; leonerd++
    rt.cpan.org 86403; dsteinbrunner++
    Add Travis configuration.
  1.26-TRIAL      2020-01-24 03:43:20 GMT
    TRIAL release only
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.25
  * BUILD: No longer ship unrequired file Debian_CPANTS.txt.
    (GH #7, thanks to real-dam)
  * BUILD: No longer mark BSD::Resource as required (GH #6).
  * TEST: Skip core-dump tests on OS X. They're not as
    straightforward as the test script would like. (GH #5).
  * BUGFIX: Silence "Statement unlikely to be reached" warning
    (Karen Etheridge)
  * BUGFIX: Repository information fix, and typo fixes (@dsteinbrunner)
  * BUILD: Converted to using dzil.
  * Same as 1.23 release, but with booched changelog. Oops! :)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sat Nov 20 2010 pascal.bleser@opensuse.org
- initial package (1.21)
